@@ -3,7 +3,7 @@ import shutil
 from pathlib import Path
 import os
     
-def setup_startup():
+def setup_startup(name="edurov"):
     system_directory = Path(__file__).parent
     systemd_user_dir = Path("/lib/systemd/system/")
 
@@ -12,9 +12,9 @@ def setup_startup():
 
     with open(system_directory / "pyedurov2.service") as source:
         with open(systemd_user_dir / "pyedurov2.service", "w") as target:
-            target.write(source.read().format(user_name = user))
+            target.write(source.read().format(user_name = user, advertising_name=name))
 
     os.system("systemctl daemon-reload")
     os.system("systemctl enable pyedurov2.service")
 
-    print("pyedurov2 service added to startup.")
\ No newline at end of file
+    print("pyedurov2 service added to startup.")
